@@ -29,7 +29,7 @@ class VNumber(AbstractParameter):
 
     def __init__(self, NA: Union[float, Callable], core_radius: float
                  ) -> None:
-        """
+        r"""
         Parameters
         ----------
         NA :
@@ -59,7 +59,7 @@ class VNumber(AbstractParameter):
     def __call__(self, omega: np.ndarray) -> np.ndarray: ...
     # ------------------------------------------------------------------
     def __call__(self, omega):
-        """Compute the V number.
+        r"""Compute the V number.
 
         Parameters
         ----------
@@ -155,4 +155,5 @@ if __name__ == "__main__":
                               "refractive index."]
 
     oc.plot2d([lambdas], [res], x_labels=x_labels, y_labels=y_labels,
-              plot_titles=plot_titles, opacity=[0.0], y_ranges=[(2., 7.)])
+              plot_titles=plot_titles, line_opacities=[0.0],
+              y_ranges=[(2., 7.)])
