@@ -44,7 +44,7 @@ class NLIndex(AbstractParameter):
                  factor: Optional[float] = None,
                  coefficients: Optional[List[Tuple[float, float]]] = None
                  ) -> None:
-        """The non linear index.
+        r"""The non linear index.
 
         Parameters
         ----------
@@ -74,7 +74,7 @@ class NLIndex(AbstractParameter):
     def __call__(self, omega: np.ndarray) -> np.ndarray: ...
     # ------------------------------------------------------------------
     def __call__(self, omega):
-        """Compute the non linear index.
+        r"""Compute the non linear index.
 
         Parameters
         ----------
@@ -185,5 +185,5 @@ if __name__ == "__main__":
                               "wavelength for Silica core."]
 
     oc.plot2d([lambdas], [res], x_labels=x_labels, y_labels=y_labels,
-               plot_titles=plot_titles, opacity=[0.0],
+               plot_titles=plot_titles, line_opacities=[0.0],
                y_ranges=[(2.5*1e-20, 3.2*1e-20)])
